@@ -309,7 +309,8 @@ class BaseEnvironnement(BaseEstimator):
         Méthode interne d'alerte de divergence du modèle pendant sa phase 
         d'apprentissage.
         """
-        if np.isnan(loss) or np.isinf(loss):
+        loss_ = loss.cpu()
+        if np.isnan(loss_) or np.isinf(loss_):
             raise DivergenceError(
                 """Verger ! L'algorithme a dit "verger" !"""
             )
@@ -652,6 +653,10 @@ class BaseEnvironnement(BaseEstimator):
                 "un pas de gradient ne sera pas effectué."
             )
 
+        # Permet de construire le modèle avec les paramètres actuels du fit.
+        if build:
+            self.build()
+
         if optimizer is not None:
             if hasattr(self, 'optimizer'):
                 warn(
@@ -667,10 +672,6 @@ class BaseEnvironnement(BaseEstimator):
 
         id_processes = str(uuid.uuid1())
 
-        # Permet de construire le modèle avec les paramètres actuels du fit.
-        if build:
-            self.build()
-
         if not isinstance(X, DataLoader):
             if isinstance(X, dict):
                 X = [X]
