@@ -9,6 +9,7 @@ from ._set_deep_params import set_params_deep
 from ._statistique import weighted_avg_and_std
 from ._transpose import (list_of_dict_2_dict_of_list,
                          dict_of_list_2_list_of_dict)
+from ._rolling import RollingWindow
 
 __all__ = (
     'Chunker',
@@ -22,5 +23,6 @@ __all__ = (
     'set_params_deep',
     'weighted_avg_and_std',
     'list_of_dict_2_dict_of_list',
-    'dict_of_list_2_list_of_dict'
+    'dict_of_list_2_list_of_dict',
+    'RollingWindow'
 )
